import { 
  select, 
  geoPath, 
  geoNaturalEarth1, 
  zoom, 
  event,
	scaleOrdinal,
  schemeSpectral
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';

const svg = select('svg');

// svg.append('g')
// 		.attr('transform', 'translate(600, 100)')
// 		.call(sizeLegend, {
//   		sizeScale,
//   		spacing: 80,
//   		textOffset: 10,
//   		nimTicks: 5,
//   		circleFill: 'rgba(0,0,0,0.5)'
// });

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

const colorLegendg = svg.append('g')
		.attr('transform', 'translate(30, 300)')

g.append('path')
    .attr('class', 'sphere')
    .attr('d', pathGenerator({type: 'Sphere'})); 

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));

const colorScale = scaleOrdinal();

const colorValue = d => d.properties.economy;

loadAndProcessData().then(countries => {
  
  colorScale.domain(countries.features.map(colorValue))
  						.domain(colorScale.domain().sort().reverse())
  						.range(schemeSpectral[colorScale.domain().length])
  
  colorLegendg.call(colorLegend, {
  		colorScale,
  		circleRadius: 8,
  		spacing: 20,
  		textOffset: 12,
    	backgroundRectWidth: 235
});
  
  g.selectAll('path').data(countries.features)
  .enter().append('path')
    .attr('class', 'country')
    .attr('title', 'Hello')
    .attr('d', pathGenerator)
    .attr('fill', d => colorScale(colorValue(d)))
  .append('title')
    .text(d => d.properties.name + ': ' + colorValue(d));
});

